import { Editor, Node, Path, Text, Value } from '..';
/**
 * `ElementEntry` objects refer to an `Element` and the `Path` where it can be
 * found inside a root node.
 */
export declare type ElementEntry = [Element, Path];
/**
 * A utility type to get all the element nodes type from a root node.
 */
export declare type ElementOf<N extends Node> = Editor<Value> extends N ? Element : Element extends N ? Element : N extends Editor<Value> ? Extract<N['children'][number], Element> | ElementOf<N['children'][number]> : N extends Element ? N | Extract<N['children'][number], Element> | ElementOf<N['children'][number]> : never;
/**
 * `Element` objects are a type of node in a Slate document that contain other
 * element nodes or text nodes. They can be either "blocks" or "inlines"
 * depending on the Slate editor's configuration.
 */
export interface Element {
    children: Array<Element | Text>;
    [key: string]: unknown;
}
export declare const Element: {
    /**
     * Check if a value implements the `Element` interface.
     */
    isElement(value: any): value is Element;
    /**
     * Check if a value is an array of `Element` objects.
     */
    isElementList(value: any): value is Element[];
    /**
     * Check if an element matches set of properties.
     *
     * Note: this checks custom properties, and it does not ensure that any
     * children are equivalent.
     */
    matches(element: Element, props: object): boolean;
};
//# sourceMappingURL=element.d.ts.map