import { Range, Editor, Element, Node, Value, NodeProps } from '..';
import { Simplify, UnionToIntersection } from '../utils/types';
/**
 * A utility type to get all the text node types from a root node type.
 */
export declare type TextOf<N extends Node> = Editor<Value> extends N ? Text : Element extends N ? Text : N extends Editor<Value> ? TextOf<N['children'][number]> : N extends Element ? Extract<N['children'][number], Text> | TextOf<N['children'][number]> : N extends Text ? N : never;
/**
 * `Text` objects represent the nodes that contain the actual text content of a
 * Slate document along with any formatting properties. They are always leaf
 * nodes in the document tree as they cannot contain any children.
 */
export interface Text {
    text: string;
    [key: string]: unknown;
}
export declare const Text: {
    /**
     * Check if two text nodes are equal.
     */
    equals(text: Text, another: Text, options?: {
        loose?: boolean;
    }): boolean;
    /**
     * Check if a value implements the `Text` interface.
     */
    isText(value: any): value is Text;
    /**
     * Check if a value is a list of `Text` objects.
     */
    isTextList(value: any): value is Text[];
    /**
     * Check if an text matches set of properties.
     *
     * Note: this is for matching custom properties, and it does not ensure that
     * the `text` property are two nodes equal.
     */
    matches<T extends Text>(text: T, props: object): boolean;
    /**
     * Get the leaves for a text node given decorations.
     */
    decorations<T_1 extends Text>(node: T_1, decorations: Range[]): T_1[];
};
/**
 * A utility type to get all the mark types from a root node type.
 */
export declare type MarksOf<N extends Node> = Simplify<UnionToIntersection<NodeProps<TextOf<N>>>>;
export declare type MarkKeysOf<N extends Node> = {} extends MarksOf<N> ? unknown : keyof MarksOf<N>;
//# sourceMappingURL=text.d.ts.map