import { Editor, Location, Path, NodeMatch, NodeOf, ElementOf, TextOf, Value } from '..';
export declare const NodeTransforms: {
    /**
     * Insert nodes at a specific location in the Editor.
     */
    insertNodes<V extends Value>(editor: Editor<V>, nodes: ElementOf<Editor<V>> | TextOf<Editor<V>> | (ElementOf<Editor<V>> | TextOf<Editor<V>>)[], options?: {
        at?: Location | undefined;
        match?: NodeMatch<NodeOf<Editor<V>>> | undefined;
        mode?: "highest" | "lowest" | undefined;
        hanging?: boolean | undefined;
        select?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    /**
     * Lift nodes at a specific location upwards in the document tree, splitting
     * their parent in two if necessary.
     */
    liftNodes<V_1 extends Value>(editor: Editor<V_1>, options?: {
        at?: Location | undefined;
        match?: NodeMatch<NodeOf<Editor<V_1>>> | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        voids?: boolean | undefined;
    }): void;
    /**
     * Merge a node at a location with the previous node of the same depth,
     * removing any empty containing nodes after the merge if necessary.
     */
    mergeNodes<V_2 extends Value>(editor: Editor<V_2>, options?: {
        at?: Location | undefined;
        match?: NodeMatch<NodeOf<Editor<V_2>>> | undefined;
        mode?: "highest" | "lowest" | undefined;
        hanging?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    /**
     * Move the nodes at a location to a new location.
     */
    moveNodes<V_3 extends Value>(editor: Editor<V_3>, options: {
        at?: Location | undefined;
        match?: NodeMatch<NodeOf<Editor<V_3>>> | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        to: Path;
        voids?: boolean | undefined;
    }): void;
    /**
     * Remove the nodes at a specific location in the document.
     */
    removeNodes<V_4 extends Value>(editor: Editor<V_4>, options?: {
        at?: Location | undefined;
        match?: NodeMatch<NodeOf<Editor<V_4>>> | undefined;
        mode?: "highest" | "lowest" | undefined;
        hanging?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    /**
     * Set new properties on the nodes at a location.
     */
    setNodes<V_5 extends Value>(editor: Editor<V_5>, props: Partial<NodeOf<Editor<V_5>>>, options?: {
        at?: Location | undefined;
        match?: NodeMatch<NodeOf<Editor<V_5>>> | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        hanging?: boolean | undefined;
        split?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    /**
     * Split the nodes at a specific location.
     */
    splitNodes<V_6 extends Value>(editor: Editor<V_6>, options?: {
        at?: Location | undefined;
        match?: NodeMatch<NodeOf<Editor<V_6>>> | undefined;
        mode?: "highest" | "lowest" | undefined;
        always?: boolean | undefined;
        height?: number | undefined;
        voids?: boolean | undefined;
    }): void;
    /**
     * Unset properties on the nodes at a location.
     */
    unsetNodes<V_7 extends Value>(editor: Editor<V_7>, props: string | string[], options?: {
        at?: Location | undefined;
        match?: NodeMatch<NodeOf<Editor<V_7>>> | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        split?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    /**
     * Unwrap the nodes at a location from a parent node, splitting the parent if
     * necessary to ensure that only the content in the range is unwrapped.
     */
    unwrapNodes<V_8 extends Value>(editor: Editor<V_8>, options?: {
        at?: Location | undefined;
        match?: NodeMatch<NodeOf<Editor<V_8>>> | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        split?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    /**
     * Wrap the nodes at a location in a new container node, splitting the edges
     * of the range first to ensure that only the content in the range is wrapped.
     */
    wrapNodes<V_9 extends Value>(editor: Editor<V_9>, element: ElementOf<Editor<V_9>>, options?: {
        at?: Location | undefined;
        match?: NodeMatch<NodeOf<Editor<V_9>>> | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        split?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
};
//# sourceMappingURL=node.d.ts.map